﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using CompositeKeyUpdate.Models;

namespace CompositeKeyUpdate.Controllers
{
    public class ScheduleController : Controller
    {
        private LocationScheduleContext db = new LocationScheduleContext();

        // GET: /Schedule/
        public ActionResult Index()
        {
            var schedule = db.Schedule.Include(s => s.Day).Include(s => s.Language).Include(s => s.Location).Include(s => s.Time);
            return View(schedule.ToList());
        }

        // GET: /Schedule/Details/5
        public ActionResult Details(int LocationID, int DayID, int TimeID, string LanguageID)
        {

            Schedule schedule = db.Schedule.Find(LocationID, TimeID, DayID, LanguageID);
            if (schedule == null)
            {
                return HttpNotFound();
            }
            return View(schedule);
        }

        // GET: /Schedule/Create
        public ActionResult Create()
        {
            ViewBag.DayID = new SelectList(db.Days, "DayID", "Day");
            ViewBag.LanguageID = new SelectList(db.Languages, "LanguageID", "Language");
            ViewBag.LocationID = new SelectList(db.Locations, "LocationID", "Location");
            ViewBag.TimeID = new SelectList(db.Times, "TimeID", "Time");
            return View();
        }

        // POST: /Schedule/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include="LocationID,DayID,TimeID,LanguageID,Notes")] Schedule schedule)
        {
            if (ModelState.IsValid)
            {
                db.Schedule.Add(schedule);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.DayID = new SelectList(db.Days, "DayID", "Day", schedule.DayID);
            ViewBag.LanguageID = new SelectList(db.Languages, "LanguageID", "Language", schedule.LanguageID);
            ViewBag.LocationID = new SelectList(db.Locations, "LocationID", "Location", schedule.LocationID);
            ViewBag.TimeID = new SelectList(db.Times, "TimeID", "Time", schedule.TimeID);
            return View(schedule);
        }

        // GET: /Schedule/Edit/5
        public ActionResult Edit(int LocationID, int DayID, int TimeID, string LanguageID)
        {

            Schedule schedule = db.Schedule.Find(LocationID, DayID, TimeID, LanguageID);
            if (schedule == null)
            {
                return HttpNotFound();
            }
            ViewBag.DayID = new SelectList(db.Days, "DayID", "Day", schedule.DayID);
            ViewBag.LanguageID = new SelectList(db.Languages, "LanguageID", "Language", schedule.LanguageID);
            ViewBag.LocationID = new SelectList(db.Locations, "LocationID", "Location", schedule.LocationID);
            ViewBag.TimeID = new SelectList(db.Times, "TimeID", "Time", schedule.TimeID);
            return View(schedule);
        }

        // POST: /Schedule/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include="LocationID,DayID,TimeID,LanguageID,Notes")] Schedule schedule)
        {
            if (ModelState.IsValid)
            {
                int OLocationID = Convert.ToInt32(Request["LocationID"]);
                int OTimeID = Convert.ToInt32(Request["TimeID"]);
                int ODayID = Convert.ToInt32(Request["DayID"]);
                string OLanguageID = Request["LanguageID"].ToString();

                var services = db.Schedule.Where(a => a.LocationID == OLocationID)
                                           .Where(a => a.TimeID == OTimeID)
                                           .Where(a => a.DayID == ODayID)
                                           .Where(a => a.LanguageID == OLanguageID);

                foreach (var s in services)
                {
                    db.Schedule.Remove(s);
                }

                db.Schedule.Add(schedule);
                try
                {
                    db.SaveChanges();
                }
                catch
                {
                    return RedirectToAction("Index");
                }
                db.Entry(schedule).State = EntityState.Modified;
                return RedirectToAction("Index");
            }
            ViewBag.DayID = new SelectList(db.Days, "DayID", "Day", schedule.DayID);
            ViewBag.LanguageID = new SelectList(db.Languages, "LanguageID", "Language", schedule.LanguageID);
            ViewBag.LocationID = new SelectList(db.Locations, "LocationID", "Location", schedule.LocationID);
            ViewBag.TimeID = new SelectList(db.Times, "TimeID", "Time", schedule.TimeID);
            return View(schedule);
        }

        // GET: /Schedule/Delete/5
        public ActionResult Delete(int LocationID, int DayID, int TimeID, string LanguageID)
        {

            Schedule schedule = db.Schedule.Find(LocationID, TimeID, DayID, LanguageID);
            if (schedule == null)
            {
                return HttpNotFound();
            }
            return View(schedule);
        }

        // POST: /Schedule/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            Schedule schedule = db.Schedule.Find(id);
            db.Schedule.Remove(schedule);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
